# Python Vcgencmd Wrapper

Python Wrapper for BCM (Raspberry Pi) vcgencmd.

This project initially created for AzatAI Xlink Clusters, where we use Raspbeery Pis as a node for our kubernets classters. They worked very well, to control and monitor the rpi nodes, we then created this package.

This package is also used in many other projects where RPi is a means of central computational power.



Still experimental.

## How to install 
`pip3 install pyvcgencmd`  
## How to use   
Quick example:  
``` python
from pyvcgencmd.models import Vcmd
```

## How to contribute    
to be documented soon.  

## Release Notes    
### Latest Changes  


## License

This project is licensed under the terms of the MIT license.